==> medlogics-common-classes-1.4.7.jar: com/floreantpos/model/PurchaseOrderItem.java <==
package com.floreantpos.model;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

import org.apache.commons.lang.StringUtils;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.floreantpos.model.base.BasePurchaseOrderItem;
import com.floreantpos.model.dao.MenuItemDAO;
import com.floreantpos.model.util.DataProvider;
import com.floreantpos.model.util.DateUtil;
import com.floreantpos.util.NumberUtil;
import com.floreantpos.util.POSUtil;
import com.google.gson.Gson;
import com.google.gson.JsonElement;

@XmlRootElement
@JsonIgnoreProperties(ignoreUnknown = true, value = { "menuItem", "purchaseOrder" })
public class PurchaseOrderItem extends BasePurchaseOrderItem implements PropertyContainer {
	private static final long serialVersionUID = 1L;
	
	private transient Map<String, Object> tmpValueMap = new HashMap<>();

	/*[CONSTRUCTOR MARKER BEGIN]*/
	public PurchaseOrderItem() {
	}

	/**
	 * Constructor for primary key
	 */
	public PurchaseOrderItem(java.lang.String id) {
		super(id);
	}

	/**
	 * Constructor for required fields
	 */
	public PurchaseOrderItem(java.lang.String id, com.floreantpos.model.PurchaseOrder purchaseOrder) {

		super(id, purchaseOrder);
	}

	/*[CONSTRUCTOR MARKER END]*/

	private Double quantityToReceive;
	private MenuItem menuItem;
	private transient com.google.gson.JsonObject propertiesContainer;
	private String unitCodeDisplay;

	public void calculatePrice() {
		setSubtotalAmount((getUnitCost() * getItemQuantity()));
		setTotalAmount((getSubtotalAmount() + getTaxAmount() - getDiscountAmount()));
	}

	public String getQuantityDisplay() {
		return NumberUtil.format6DigitNumber(super.getItemQuantity());
	}

	public String getCostDisplay() {
		return NumberUtil.getCurrencyFormatWithoutCurrencySymbol(super.getUnitCost());
	}

	public String getTotalDisplay() {
		return NumberUtil.getCurrencyFormatWithoutCurrencySymbol(super.getTotalAmount());
	}

	public Double getQuantityToReceive() {
		return quantityToReceive == null ? Double.valueOf(0) : quantityToReceive;
	}

	public void setQuantityToReceive(Double quantityToReceive) {
		this.quantityToReceive = quantityToReceive;
	}

	@Override
	public void addProperty(String key, String value) {
		initPropertyContainer();
		propertiesContainer.addProperty(key, value);
		super.setProperties(propertiesContainer.toString());
	}

	@Override
	public String getProperty(String key) {
		initPropertyContainer();

		if (propertiesContainer.has(key)) {
			JsonElement jsonElement = propertiesContainer.get(key);
			if (!jsonElement.isJsonNull()) {
				return jsonElement.getAsString();
			}
		}
		return null;
	}

	@Override
	public boolean hasProperty(String key) {
		return getProperty(key) != null;
	}

	public boolean isPropertyValueTrue(String propertyName) {
		String property = getProperty(propertyName);

		return POSUtil.getBoolean(property);
	}

	@Override
	public void removeProperty(String propertyName) {
		initPropertyContainer();
		propertiesContainer.remove(propertyName);
		super.setProperties(propertiesContainer.toString());
	}

	@Override
	public com.google.gson.JsonObject getPropertyStore() {
		initPropertyContainer();
		return propertiesContainer;
	}

	private void initPropertyContainer() {
		if (propertiesContainer == null) {
			if (StringUtils.isBlank(super.getProperties())) {
				propertiesContainer = new com.google.gson.JsonObject();
			}
			else {
				propertiesContainer = new Gson().fromJson(super.getProperties(), com.google.gson.JsonObject.class);
			}
		}
	}

	@XmlTransient
	public MenuItem getMenuItem() {
		if (menuItem == null) {
			String itemId = getMenuItemId();
			if (StringUtils.isEmpty(itemId)) {
				return null;
			}
			menuItem = MenuItemDAO.getInstance().loadInitialized(itemId);
		}

		return menuItem;
	}

	public void setMenuItem(MenuItem menuItem) {
		this.menuItem = menuItem;
	}

	public String getUnitCodeDisplay() {
		String unitId = getItemUnitName();
		if (StringUtils.isBlank(unitCodeDisplay) && StringUtils.isNotBlank(unitId)) {
			if (UnitType.match(getUnitType(), UnitType.PACKAGING_UNIT)) {
				InventoryStockUnit inventoryStockUnit = (InventoryStockUnit) DataProvider.get().getObjectOf(InventoryStockUnit.class, unitId);
				return inventoryStockUnit == null ? unitCodeDisplay : inventoryStockUnit.getName();
			}
			IUnit unit = DataProvider.get().getInventoryUnitById(unitId);
			return unit == null ? "" : StringUtils.isBlank(unit.getDisplayName()) ? unit.getName() : unit.getDisplayName();
		}
		return unitCodeDisplay;
	}

	public void setUnitCodeDisplay(String unitName) {
		this.unitCodeDisplay = unitName;
	}

	public String getExpireDateDisplay() {
		Date expireDate = getExpireDate();
		if (expireDate == null) {
			return "";
		}
		return DateUtil.formatDateWithoutTime(expireDate);
	}

	@Override
	public String toString() {
		if (StringUtils.isBlank(getBatchNumber())) {
			return "";
		}
		return getBatchNumber();
	}

	public void putUnitType(String unitType) {
		addProperty("unit.type", unitType);
	}

	public String getUnitType() {
		return getProperty("unit.type");
	}

	public void logJournal(PurchaseOrder purchaseOrder, String action) {
//		String action = isEdited ? ActionHistory.PURCHASE_ITEM_EDITED : ActionHistory.PURCHASE_ITEM_ADDED;
		String description = "Item name: " + getName(); //$NON-NLS-1$
		description += StringUtils.isNotBlank(getId()) ? ", PurchaseOrderItem id: " + getId() : ", MenuItem id: " + getMenuItemId(); //$NON-NLS-1$ //$NON-NLS-2$

		StringBuilder builder = new StringBuilder(description);
		builder.append(", Price: " + getTotalAmount());
		if (getDiscountAmount() > 0) {
			builder.append(", Discount: " + getDiscountAmount());
		}
		purchaseOrder.addRandomEvent(action, builder.toString());
	}

	public void logJournalForGoodsAndServiceItem(PurchaseOrder purchaseOrder) {
		String description = "Item name: " + getName(); //$NON-NLS-1$
		description += StringUtils.isNotBlank(getId()) ? ", PurchaseOrderItem id: " + getId() : ", MenuItem id: " + getMenuItemId(); //$NON-NLS-1$ //$NON-NLS-2$
		purchaseOrder.addRandomEvent(ActionHistory.PURCHASE_ITEM_ADDED, description);
	}
	
	public void putTmpValue(String key, Object value) {
		tmpValueMap.put(key, value);
	}

	public <T> T getTmpValue(String key) {
		Object object = tmpValueMap.get(key);
		if (object == null) {
			return null;
		}
		return (T) object;
	}
}

==> medlogics-common-classes-1.6.0.jar: com/floreantpos/model/PurchaseOrderItem.java <==
package com.floreantpos.model;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

import org.apache.commons.lang.StringUtils;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.floreantpos.model.base.BasePurchaseOrderItem;
import com.floreantpos.model.dao.MenuItemDAO;
import com.floreantpos.model.util.DataProvider;
import com.floreantpos.model.util.DateUtil;
import com.floreantpos.util.NumberUtil;
import com.floreantpos.util.POSUtil;
import com.google.gson.Gson;
import com.google.gson.JsonElement;

@XmlRootElement
@JsonIgnoreProperties(ignoreUnknown = true, value = { "menuItem", "purchaseOrder" })
public class PurchaseOrderItem extends BasePurchaseOrderItem implements PropertyContainer {
	private static final long serialVersionUID = 1L;
	
	private transient Map<String, Object> tmpValueMap = new HashMap<>();

	/*[CONSTRUCTOR MARKER BEGIN]*/
	public PurchaseOrderItem () {
    }

	/**
	 * Constructor for primary key
	 */
	public PurchaseOrderItem (java.lang.String id) {
		super(id);
	}

	/**
	 * Constructor for required fields
	 */
	public PurchaseOrderItem (
		java.lang.String id,
		com.floreantpos.model.PurchaseOrder purchaseOrder) {

		super (
			id,
			purchaseOrder);
	}

	/*[CONSTRUCTOR MARKER END]*/

	private Double quantityToReceive;
	private MenuItem menuItem;
	private transient com.google.gson.JsonObject propertiesContainer;
	private String unitCodeDisplay;

	public void calculatePrice() {
		setSubtotalAmount((getUnitCost() * getItemQuantity()));
		setTotalAmount((getSubtotalAmount() + getTaxAmount() - getDiscountAmount()));
	}

	public String getQuantityDisplay() {
		return NumberUtil.format6DigitNumber(super.getItemQuantity());
	}

	public String getCostDisplay() {
		return NumberUtil.getCurrencyFormatWithoutCurrencySymbol(super.getUnitCost());
	}

	public String getTotalDisplay() {
		return NumberUtil.getCurrencyFormatWithoutCurrencySymbol(super.getTotalAmount());
	}

	public Double getQuantityToReceive() {
		return quantityToReceive == null ? Double.valueOf(0) : quantityToReceive;
	}

	public void setQuantityToReceive(Double quantityToReceive) {
		this.quantityToReceive = quantityToReceive;
	}

	@Override
	public void addProperty(String key, String value) {
		initPropertyContainer();
		propertiesContainer.addProperty(key, value);
		super.setProperties(propertiesContainer.toString());
	}

	@Override
	public String getProperty(String key) {
		initPropertyContainer();

		if (propertiesContainer.has(key)) {
			JsonElement jsonElement = propertiesContainer.get(key);
			if (!jsonElement.isJsonNull()) {
				return jsonElement.getAsString();
			}
		}
		return null;
	}

	@Override
	public boolean hasProperty(String key) {
		return getProperty(key) != null;
	}

	public boolean isPropertyValueTrue(String propertyName) {
		String property = getProperty(propertyName);

		return POSUtil.getBoolean(property);
	}

	@Override
	public void removeProperty(String propertyName) {
		initPropertyContainer();
		propertiesContainer.remove(propertyName);
		super.setProperties(propertiesContainer.toString());
	}

	@Override
	public com.google.gson.JsonObject getPropertyStore() {
		initPropertyContainer();
		return propertiesContainer;
	}

	private void initPropertyContainer() {
		if (propertiesContainer == null) {
			if (StringUtils.isBlank(super.getProperties())) {
				propertiesContainer = new com.google.gson.JsonObject();
			}
			else {
				propertiesContainer = new Gson().fromJson(super.getProperties(), com.google.gson.JsonObject.class);
			}
		}
	}

	@XmlTransient
	public MenuItem getMenuItem() {
		if (menuItem == null) {
			String itemId = getMenuItemId();
			if (StringUtils.isEmpty(itemId)) {
				return null;
			}
			menuItem = MenuItemDAO.getInstance().loadInitialized(itemId);
		}

		return menuItem;
	}

	public void setMenuItem(MenuItem menuItem) {
		this.menuItem = menuItem;
	}

	public String getUnitCodeDisplay() {
		String unitId = getItemUnitName();
		if (StringUtils.isBlank(unitCodeDisplay) && StringUtils.isNotBlank(unitId)) {
			if (UnitType.match(getUnitType(), UnitType.PACKAGING_UNIT)) {
				InventoryStockUnit inventoryStockUnit = (InventoryStockUnit) DataProvider.get().getObjectOf(InventoryStockUnit.class, unitId);
				return inventoryStockUnit == null ? unitCodeDisplay : inventoryStockUnit.getName();
			}
			IUnit unit = DataProvider.get().getInventoryUnitById(unitId);
			return unit == null ? "" : StringUtils.isBlank(unit.getDisplayName()) ? unit.getName() : unit.getDisplayName();
		}
		return unitCodeDisplay;
	}

	public void setUnitCodeDisplay(String unitName) {
		this.unitCodeDisplay = unitName;
	}

	public String getExpireDateDisplay() {
		Date expireDate = getExpireDate();
		if (expireDate == null) {
			return "";
		}
		return DateUtil.formatDateWithoutTime(expireDate);
	}

	@Override
	public String toString() {
		if (StringUtils.isBlank(getBatchNumber())) {
			return "";
		}
		return getBatchNumber();
	}

	public void putUnitType(String unitType) {
		addProperty("unit.type", unitType);
	}

	public String getUnitType() {
		return getProperty("unit.type");
	}

	public void logJournal(PurchaseOrder purchaseOrder, String action) {
//		String action = isEdited ? ActionHistory.PURCHASE_ITEM_EDITED : ActionHistory.PURCHASE_ITEM_ADDED;
		String description = "Item name: " + getName(); //$NON-NLS-1$
		description += StringUtils.isNotBlank(getId()) ? ", PurchaseOrderItem id: " + getId() : ", MenuItem id: " + getMenuItemId(); //$NON-NLS-1$ //$NON-NLS-2$

		StringBuilder builder = new StringBuilder(description);
		builder.append(", Price: " + getTotalAmount());
		if (getDiscountAmount() > 0) {
			builder.append(", Discount: " + getDiscountAmount());
		}
		purchaseOrder.addRandomEvent(action, builder.toString());
	}

	public void logJournalForGoodsAndServiceItem(PurchaseOrder purchaseOrder) {
		String description = "Item name: " + getName(); //$NON-NLS-1$
		description += StringUtils.isNotBlank(getId()) ? ", PurchaseOrderItem id: " + getId() : ", MenuItem id: " + getMenuItemId(); //$NON-NLS-1$ //$NON-NLS-2$
		purchaseOrder.addRandomEvent(ActionHistory.PURCHASE_ITEM_ADDED, description);
	}
	
	public void putTmpValue(String key, Object value) {
		tmpValueMap.put(key, value);
	}

	public <T> T getTmpValue(String key) {
		Object object = tmpValueMap.get(key);
		if (object == null) {
			return null;
		}
		return (T) object;
	}
}
